WidgetElementBuilder class

A custom Markdown element builder that renders the 'widgetBlock' elements created by the WidgetBlockSyntax into actual Flutter widgets, fetching builders from the Provided registry.

Constructors

WidgetElementBuilder({required SendCommandCallback sendCommandCallback})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendCommandCallback SendCommandCallback
final

Methods

isBlockElement() bool
For block syntax has to return true.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
visitElementAfter(Element element, TextStyle? preferredStyle) Widget?
Called when an Element has been reached, after its children have been visited.
inherited
visitElementAfterWithContext(BuildContext context, Element element, TextStyle? preferredStyle, TextStyle? parentStyle) Widget?
Called when an Element has been reached, after its children have been visited.
visitElementBefore(Element element) → void
Called when an Element has been reached, before its children have been visited.
visitText(Text text, TextStyle? preferredStyle) Widget?
Called when a text node has been reached.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited