registry/embedded_widget_metadata library
Classes
- EmbeddedWidgetMetadata
- Metadata describing an embedded widget type, used by the registry and potentially LLM.
- WidgetEntry
- Helper class to store the builder function and its metadata together in the registry.