EmbeddedWidgetRegistry class

Central registry for all available embedded widget builders and their metadata. This class should be provided high up in the widget tree using Provider.

Constructors

EmbeddedWidgetRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllMetadata() Map<String, EmbeddedWidgetMetadata>
Gets metadata for all registered widgets, useful for exposing to backend/LLM.
getBuilder(String label) WidgetBuildFunction?
Gets the builder function for a given widget label.
getMetadata(String label) EmbeddedWidgetMetadata?
Gets the metadata for a given widget label.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerWidget({required String label, required WidgetBuildFunction builder, required EmbeddedWidgetMetadata metadata}) → void
Registers a single widget builder and its metadata.
registerWidgetLibrary(Map<String, WidgetEntry> libraryEntries) → void
Registers a collection of widget builders and metadata (e.g., from a library).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited