getBuilder method
Gets the builder function for a given widget label.
Implementation
WidgetBuildFunction? getBuilder(String label) {
return _registry[label]?.builder;
}
Gets the builder function for a given widget label.
WidgetBuildFunction? getBuilder(String label) {
return _registry[label]?.builder;
}