SendCommandCallback typedef
Define the interface for sending commands from embedded widgets to the backend/controller. This typedef represents a function that takes a command type string and a map of arguments, and returns void (or Future
Implementation
typedef SendCommandCallback = void Function(String commandType, Map<String, dynamic> args);