widgets/conversation_message library

Classes

ConversationMessage
A widget that renders Markdown content and embeds custom widgets based on special syntax blocks. This widget is intended to be used for displaying individual messages in a conversation UI, typically within a list of messages.