widgets/core/core_widgets_registration library

Functions

registerCoreWidgets(EmbeddedWidgetRegistry registry) → void
Registers all core embedded widgets with the provided registry. This function is typically called by the global registration function.