markdown/widget_element_builder library
Classes
- WidgetElementBuilder
- A custom Markdown element builder that renders the 'widgetBlock' elements created by the WidgetBlockSyntax into actual Flutter widgets, fetching builders from the Provided registry.