EmbeddedWidgetMetadata class

Metadata describing an embedded widget type, used by the registry and potentially LLM.

Constructors

EmbeddedWidgetMetadata({required String description, required Map<String, dynamic> parameterSchema})

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
parameterSchema Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLlmDescription() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited