Define the interface for sending commands from embedded widgets to the backend/controller.
This typedef represents a function that takes a command type string and a map
of arguments, and returns void (or Future
Define the typedef for the function that builds an embedded widget.
It receives the BuildContext, parameters from the JSON block, and the SendCommandCallback.